/******************************************************************************

  ble.h 

  driver for BLE protocol configuration and operation

******************************************************************************/
#ifndef _BLE_PUMP_H_
#define _BLE_PUMP_H_

typedef enum
{
	BLE_STATE_IDLE,
	BLE_STATE_ADV,
	BLE_STATE_CONNECTED,
	BLE_STATE_DISCONNECTED
	
}BLE_COMMUNICATION_STATES_t;


// Callback on data reception
typedef void (*app_tj_data_handler_t) (uint8_t const *data_p, uint16_t length);

// Callback on state change
typedef void (*app_tj_state_handler_t) (BLE_COMMUNICATION_STATES_t new_state);

// Last TX'ed packet transmission completed
typedef void (*app_tj_tx_completed_handler_t) (void);

typedef void (*app_tj_rssi_crossed_t) (int8_t rssi);


// Authentication requested
typedef bool (*app_tj_auth_handler_t) (uint8_t const *mac, uint8_t *key, uint16_t length);

// The TX power shall be one of those:
// tx_power Radio transmit power in dBm (accepted values are -40,  -20, -16, -12, -8, -4, 0, and 4 dBm).

void BLE_do_init(uint16_t advertise_interval,uint16_t  connection_interval_min,
              	uint16_t  connection_interval_max, uint16_t  slave_latency,
                uint16_t  supervision_timeout, int16_t  tx_power);

// The channel map includes 3 LSB's: each bit represents if the channel enabled (1) or disabled(0)
// The TX power shall be one of those:
// tx_power Radio transmit power in dBm (accepted values are -40,  -20, -16, -12, -8, -4, 0, and 4 dBm).
void BLE_do_adv_start(uint16_t channel_map, int16_t tx_power);

// Function to indicate on state changed of the device
void BLE_register_callbacks(app_tj_data_handler_t dataCB, app_tj_state_handler_t stateCB, app_tj_tx_completed_handler_t txCompleteCB, app_tj_auth_handler_t authCB);

// Send data in response to command over BLE
uint32_t BLE_send_command_response(uint8_t  *data_p, uint16_t length);

// Send asynchronous event in case the device is connected
uint32_t BLE_send_event(uint8_t  *data_p, uint16_t length);

// Update ADV interval if required
void BLE_do_change_adv_interval(uint16_t advertise_interval);

// Read the current RSSI value. If not registered for notifications already - read will not be performed
void BLE_get_rssi(int8_t *rssi);

// Register/unregister for RSSI notifications on the existing connection
void BLE_callback_rssi_threshold_crossed(int8_t threshold, app_tj_rssi_crossed_t cb);



#endif
