/**
 * Copyright (c) 2014 - 2017, Nordic Semiconductor ASA
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 * 
 * 3. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 * 
 * 4. This software, with or without modification, must only be used with a
 *    Nordic Semiconductor ASA integrated circuit.
 * 
 * 5. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 * 
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
/** @file
 *
 * @defgroup ble_sdk_uart_over_ble_main main.c
 * @{
 * @ingroup  ble_sdk_app_nus_eval
 * @brief    UART over BLE application main file.
 *
 * This file contains the source code for a sample application that uses the Nordic UART service.
 * This application uses the @ref srvlib_conn_params module.
 */

#include "interrupts.h"
#include <stdint.h>
#include <string.h>
#include "nordic_common.h"
#include "nrf.h"
#include "ble_hci.h"
#include "ble_advdata.h"
#include "ble_advertising.h"
#include "ble_conn_params.h"
#include "nrf_sdh.h"
#include "nrf_sdh_soc.h"
#include "nrf_sdh_ble.h"
#include "nrf_ble_gatt.h"
#include "app_timer.h"
#include "app_util_platform.h"
#include "bsp_btn_ble.h"
#include "ble_pump.h"
#include "nrf_delay.h"
#include "nrf_drv_wdt.h"
#include "nrf_drv_clock.h"

#include "nrf_log.h"
#include "nrf_log_ctrl.h"
#include "nrf_log_default_backends.h"
#include "app_util_platform.h"
#include "nrf_drv_twi.h"
#include "nrf_drv_swi.h"
#include "nrf_delay.h"
#include "nrf_drv_timer.h"
#include "nrf_drv_qdec.h"
#include "app_scheduler.h"
#include "nordic_common.h"
#include "nrf_drv_saadc.h"

#define DEAD_BEEF                       0xDEADBEEF                                  /**< Value used as error code on stack dump, can be used to identify stack location on stack unwind. */

APP_TIMER_DEF(m_event_timer_id);
static uint16_t   m_conn_handle          = BLE_CONN_HANDLE_INVALID;                 /**< Handle of the current connection. */


static void timer_1sec_handler(void * p_context)
{
  int_high_pr_generate(INT_1SEC);
}

/**@brief Function for the Timer initialization.
 *
 * @details Initializes the timer module.
 */
static void timers_init(void)
{
    // Initialize timer module,/ making it use the scheduler
    ret_code_t err_code = app_timer_init();
    APP_ERROR_CHECK(err_code);

    // repeated 1 sec timer     
    err_code = app_timer_create(&m_event_timer_id, APP_TIMER_MODE_REPEATED, timer_1sec_handler);
    APP_ERROR_CHECK(err_code);
    app_timer_start(m_event_timer_id, (APP_TIMER_CLOCK_FREQ / 1 ), NULL);
}

void timer_1sec_handler_swi(void)
{
  static int t = 0;
  t++;
  if ( t > 5 && (t & 3)==0 )
  {
    void a2d_test(void);
    a2d_test();
  }
}

/**@brief Function for putting the chip into sleep mode.
 *
 * @note This function will not return.
 */
static void sleep_mode_enter(void)
{
    uint32_t err_code;
#if HW_REV==HW_REV_NORDIC_EVAL_10040_S132
    err_code = bsp_indication_set(BSP_INDICATE_IDLE);
    APP_ERROR_CHECK(err_code);

    // Prepare wakeup buttons.
    err_code = bsp_btn_ble_sleep_mode_prepare();
    APP_ERROR_CHECK(err_code);
#endif
    
    // Go to system-off mode (this function will not return; wakeup will cause a reset).
    err_code = sd_power_system_off();
    APP_ERROR_CHECK(err_code);
}

/**@brief Function for handling events from the BSP module.
 *
 * @param[in]   event   Event generated by button press.
 */
void bsp_event_handler(bsp_event_t event)
{
    uint32_t err_code;
    switch (event)
    {
        case BSP_EVENT_SLEEP:
            sleep_mode_enter();
            break;

        case BSP_EVENT_DISCONNECT:
            err_code = sd_ble_gap_disconnect(m_conn_handle, BLE_HCI_REMOTE_USER_TERMINATED_CONNECTION);
            if (err_code != NRF_ERROR_INVALID_STATE)
            {
                APP_ERROR_CHECK(err_code);
            }
            break;

        case BSP_EVENT_WHITELIST_OFF:
            if (m_conn_handle == BLE_CONN_HANDLE_INVALID)
            {
                
            }
            break;

        default:
            break;
    }
}

#if HW_REV==HW_REV_NORDIC_EVAL_10040_S132
/**@brief Function for initializing buttons and leds.
 *
 * @param[out] p_erase_bonds  Will be true if the clear bonding button was pressed to wake the application up.
 */
static void buttons_leds_init(bool * p_erase_bonds)
{
    bsp_event_t startup_event;

    uint32_t err_code = bsp_init(BSP_INIT_LED | BSP_INIT_BUTTONS, bsp_event_handler);
    APP_ERROR_CHECK(err_code);

    err_code = bsp_btn_ble_init(NULL, &startup_event);
    APP_ERROR_CHECK(err_code);

    *p_erase_bonds = (startup_event == BSP_EVENT_CLEAR_BONDING_DATA);
}
#endif

/**@brief Function for initializing the nrf log module.
 */
static void log_init(void)
{
    ret_code_t err_code = NRF_LOG_INIT(NULL);
    APP_ERROR_CHECK(err_code);

    NRF_LOG_DEFAULT_BACKENDS_INIT();
}


/**@brief Function for placing the application in low power state while waiting for events.
 */
static void power_manage(void)
{
    ret_code_t err_code = sd_app_evt_wait();
    APP_ERROR_CHECK(err_code);
}

/*******************************************************************************
 
  system_fatal

*******************************************************************************/
// omri-todo - proper ahndling required 
#if HW_REV==HW_REV_NORDIC_EVAL_10040_S132 || DEBUG_MODE
#pragma optimize=none 
#endif
int system_fatal(volatile int code)
{
#if HW_REV==HW_REV_NORDIC_EVAL_10040_S132 || DEBUG_MODE
  while (code) // breakpoint to detect fatal events 
  {}
#else
  NVIC_SystemReset();
#endif  
  return 0;
}

void assert_nrf_callback(uint16_t line_num, const uint8_t * file_name)
{
  NRF_BREAKPOINT_COND;
  NVIC_SystemReset();
}

void app_error_fault_handler(uint32_t id, uint32_t pc, uint32_t info)
{
  if ( id==NRF_FAULT_ID_SDK_ERROR ) // breakpoint to detect fault events  
  {
    error_info_t *error_info = (error_info_t *)info;
    if ( error_info->line_num>0 )
    {
    }
    else
    {
    }
  }
  
  NRF_BREAKPOINT_COND;
  NVIC_SystemReset();
}

#if WDT_ENABLED && !TEST_ENABLE   
/**
 * @brief WDT events handler.
 */
void wdt_event_handler(void)
{
  //NOTE: The max amount of time we can spend in WDT interrupt is two cycles of 32768[Hz] clock - after that, reset occurs
}
#endif    

/*******************************************************************************
 
  main 

*******************************************************************************/
int main(void)
{
  // Initialize timers prior to init of BLE since BLE assumes they are initialized
  timers_init(); // breakpoint to detect unexpected resets 
  log_init();
  int_init();
#if HW_REV==HW_REV_NORDIC_EVAL_10040_S132
  bool erase_bonds;
  buttons_leds_init(&erase_bonds);
#endif
    uint32_t err_code = NRF_SUCCESS;
#if WDT_ENABLED && !TEST_ENABLE   
    nrf_drv_wdt_channel_id m_channel_id;
    err_code = nrf_drv_clock_init();
    APP_ERROR_CHECK(err_code);
    nrf_drv_clock_lfclk_request(NULL);

    nrf_drv_wdt_config_t config = NRF_DRV_WDT_DEAFULT_CONFIG;
    err_code = nrf_drv_wdt_init(&config, wdt_event_handler);
    APP_ERROR_CHECK(err_code);
    err_code = nrf_drv_wdt_channel_alloc(&m_channel_id);
    APP_ERROR_CHECK(err_code);
    nrf_drv_wdt_enable();
#endif    
    
  /*****************************************************************************
  
    TJ init 
  
  *****************************************************************************/
    
  BLE_do_init(1000,   // 1000 1advertise_interval
              150,  // connection_interval_min
              250,  // connection_interval_max
              0,    // slave_latency
              1000, // supervision_timeout
              -8);  // tx_power

  // enable the dcdc and set 0 db tx power 
  err_code = sd_power_dcdc_mode_set(NRF_POWER_DCDC_ENABLE);
  APP_ERROR_CHECK(err_code);
  err_code = sd_ble_gap_tx_power_set(0); 
  APP_ERROR_CHECK(err_code);
  
  // Enter main loop.
  for (;;)
  {
    if (NRF_LOG_PROCESS() == false)
    {
      //PROFILE(6)
#if WDT_ENABLED && !TEST_ENABLE   
      nrf_drv_wdt_channel_feed(m_channel_id);
#endif      
      power_manage();
    }
  }
}
